@@ -47,35 +47,34 @@ $stomper->subscribe(
   id          => $sub_id,
   destination => $dst,
 
-  { on_receipt => sub {
-      my $err = $_[1];
-
-      if ( defined $err ) {
-        warn $err->message . "\n";
-        $cv->send;
-
-        return;
-      }
-
-      print "Subscribed to $sub_id\n";
-
-      $stomper->send(
-        destination => $dst,
-        persistent  => 'true',
-        body        => 'Hello, world!',
-      );
-    },
-
-    on_message => sub {
-      my $msg = shift;
-
-      my $headers = $msg->headers;
-      my $body    = $msg->body;
-
-      print "Consumed: $body\n";
+  on_receipt => sub {
+    my $err = $_[1];
 
+    if ( defined $err ) {
+      warn $err->message . "\n";
       $cv->send;
-    },
+
+      return;
+    }
+
+    print "Subscribed to $sub_id\n";
+
+    $stomper->send(
+      destination => $dst,
+      persistent  => 'true',
+      body        => 'Hello, world!',
+    );
+  },
+
+  on_message => sub {
+    my $msg = shift;
+
+    my $headers = $msg->headers;
+    my $body    = $msg->body;
+
+    print "Consumed: $body\n";
+
+    $cv->send;
   }
 );
 
