@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use base qw( Exporter );
 
-our $VERSION = '0.08';
+our $VERSION = '0.10';
 
 use AnyEvent::Stomper::Frame;
 use AnyEvent::Stomper::Error;
@@ -379,29 +379,31 @@ sub _prepare {
   my $cmd_name = uc(shift);
   my $args     = shift;
 
-  my $cbs;
-  if ( ref( $args->[-1] ) eq 'HASH' ) {
-    $cbs = pop @{$args};
-  }
-  else {
-    $cbs = {};
-    if ( ref( $args->[-1] ) eq 'CODE' ) {
-      if ( $cmd_name eq 'SUBSCRIBE' ) {
-        $cbs->{on_message} = pop @{$args};
-      }
-      else {
-        $cbs->{on_receipt} = pop @{$args};
-      }
+  my %cbs;
+  if ( ref( $args->[-1] ) eq 'CODE'
+    && scalar @{$args} % 2 > 0 )
+  {
+    if ( $cmd_name eq 'SUBSCRIBE' ) {
+      $cbs{on_message} = pop @{$args};
+    }
+    else {
+      $cbs{on_receipt} = pop @{$args};
     }
   }
   my %cmd_headers = @{$args};
-  my $body        = delete $cmd_headers{body};
+  if ( defined $cmd_headers{on_receipt} ) {
+    $cbs{on_receipt} = delete $cmd_headers{on_receipt};
+  }
+  if ( defined $cmd_headers{on_message} ) {
+    $cbs{on_message} = delete $cmd_headers{on_message};
+  }
+  my $body = delete $cmd_headers{body};
 
   my $cmd = {
     name    => $cmd_name,
     headers => \%cmd_headers,
     body    => $body,
-    %{$cbs},
+    %cbs,
   };
 
   unless ( defined $cmd->{on_receipt} ) {
@@ -880,30 +882,29 @@ AnyEvent::Stomper - Flexible non-blocking STOMP client
     id          => 'foo',
     destination => '/queue/foo',
 
-    { on_receipt => sub {
-        my $err = $_[1];
-
-        if ( defined $err ) {
-          warn $err->message . "\n";
-          $cv->send;
-
-          return;
-        }
-
-        $stomper->send(
-          destination => '/queue/foo',
-          body        => 'Hello, world!',
-        );
-      },
-
-      on_message => sub {
-        my $msg = shift;
-
-        my $body = $msg->body;
-        print "Consumed: $body\n";
+    on_receipt => sub {
+      my $err = $_[1];
 
+      if ( defined $err ) {
+        warn $err->message . "\n";
         $cv->send;
-      },
+
+        return;
+      }
+
+      $stomper->send(
+        destination => '/queue/foo',
+        body        => 'Hello, world!',
+      );
+    },
+
+    on_message => sub {
+      my $msg = shift;
+
+      my $body = $msg->body;
+      print "Consumed: $body\n";
+
+      $cv->send;
     }
   );
 
@@ -1004,7 +1005,7 @@ Disabled by default.
 =item reconnect_interval => $reconnect_interval
 
 If the parameter is specified, the client will try to reconnect only after
-this interval. Commands executed between reconnections will be queued.
+this interval. Commands executed between performance will be queued.
 
   reconnect_interval => 5,
 
@@ -1019,7 +1020,7 @@ Specifies L<AnyEvent::Handle> parameters.
     linger   => 60,
   }
 
-Enabling of the C<autocork> parameter can improve perfomance. See
+Enabling of the C<autocork> parameter can improve performance. See
 documentation on L<AnyEvent::Handle> for more information.
 
 =item on_connect => $cb->()
@@ -1048,9 +1049,12 @@ an error messages to C<STDERR>.
 
 =head1 COMMAND METHODS
 
-To execute the STOMP command you must call appropriate method. The client
-automatically adds C<content-length> header to all outgoing frames. The body of
-the frame you can specify in C<body> parameter of the command method.
+To execute the STOMP command you must call appropriate method. STOMP headers
+can be specified as command parameters. The client automatically adds
+C<content-length> header to all outgoing frames. Every command method can also
+accept two additional parameters: the C<body> parameter where you can specify
+the body of the frame, and the C<on_receipt> parameter that is the alternative
+way to specify the command callback.
 
 If you want to receive C<RECEIPT> frame, you must specify C<receipt> header.
 The C<receipt> header can take special value C<auto>. In this case the
@@ -1063,8 +1067,8 @@ For commands C<SUBSCRIBE>, C<UNSUBSCRIBE>, C<DISCONNECT> the client
 automatically adds C<receipt> header for internal usage.
 
 The command callback is called after successful sending of the command to the
-server or when C<RECEIPT> frame will be received, in case if C<receipt> header
-is specified. If any error occurred during the command execution, the error
+server or when C<RECEIPT> frame will be received if C<receipt> header
+was specified. If any error occurred during the command execution, the error
 object is passed to the callback in second argument. Error object is the
 instance of the class L<AnyEvent::Stomper::Error>.
 
@@ -1075,7 +1079,7 @@ The full list of all available headers for every command you can find in STOMP
 protocol specification and in documentation on your STOMP server. For various
 versions of STOMP protocol and various STOMP servers they can be differ.
 
-=head2 send( [ %headers ] [, $cb->( $receipt, $err ) ] )
+=head2 send( [ %params ] [, $cb->( $receipt, $err ) ] )
 
 Sends a message to a destination in the messaging system.
 
@@ -1108,7 +1112,7 @@ Sends a message to a destination in the messaging system.
     receipt     => 'auto',
     body        => 'Hello, world!',
 
-    sub {
+    on_receipt => sub {
       my $receipt = shift;
       my $err     = shift;
 
@@ -1126,7 +1130,7 @@ Sends a message to a destination in the messaging system.
     }
   );
 
-=head2 subscribe( [ %headers, ] ( $cb->( $msg ) | \%cbs ) )
+=head2 subscribe( [ %params ] [, $cb->( $msg ) ] )
 
 The method is used to register to listen to a given destination. The
 C<subscribe> method require the C<on_message> callback, which is called on
@@ -1154,33 +1158,32 @@ callback, this callback will be act as C<on_message> callback.
     destination => '/queue/foo',
     ack         => 'client',
 
-    { on_receipt => sub {
-        my $receipt = shift;
-        my $err     = shift;
+    on_receipt => sub {
+      my $receipt = shift;
+      my $err     = shift;
 
-        if ( defined $err ) {
-          my $err_msg   = $err->message;
-          my $err_code  = $err->code;
-          my $err_frame = $err->frame;
+      if ( defined $err ) {
+        my $err_msg   = $err->message;
+        my $err_code  = $err->code;
+        my $err_frame = $err->frame;
 
-          return;
-        }
+        return;
+      }
 
-        # receipt handling...
-      },
+      # receipt handling...
+    },
 
-      on_message => sub {
-        my $msg = shift;
+    on_message => sub {
+      my $msg = shift;
 
-        my $headers = $msg->headers;
-        my $body    = $msg->body;
+      my $headers = $msg->headers;
+      my $body    = $msg->body;
 
-        # message handling...
-      },
+      # message handling...
     }
   );
 
-=head2 unsubscribe( [ %headers ] [, $cb->( $receipt, $err ) ] )
+=head2 unsubscribe( [ %params ] [, $cb->( $receipt, $err ) ] )
 
 The method is used to remove an existing subscription.
 
@@ -1204,7 +1207,7 @@ The method is used to remove an existing subscription.
     }
   );
 
-=head2 ack( [ %headers ] [, $cb->( $receipt, $err ) ] )
+=head2 ack( [ %params ] [, $cb->( $receipt, $err ) ] )
 
 The method is used to acknowledge consumption of a message from a subscription
 using C<client> or C<client-individual> acknowledgment. Any messages received
@@ -1233,7 +1236,7 @@ message has been acknowledged via an C<ack()> method.
     }
   );
 
-=head2 nack( [ %headers ] [, $cb->( $receipt, $err ) ] )
+=head2 nack( [ %params ] [, $cb->( $receipt, $err ) ] )
 
 The C<nack> method is the opposite of C<ack> method. It is used to tell the
 server that the client did not consume the message.
@@ -1260,19 +1263,19 @@ server that the client did not consume the message.
     }
   );
 
-=head2 begin( [ %headers ] [, $cb->( $receipt, $err ) ] )
+=head2 begin( [ %params ] [, $cb->( $receipt, $err ) ] )
 
 The method C<begin> is used to start a transaction.
 
-=head2 commit( [ %headers ] [, $cb->( $receipt, $err ) ] )
+=head2 commit( [ %params ] [, $cb->( $receipt, $err ) ] )
 
 The method C<commit> is used to commit a transaction.
 
-=head2 abort( [ %headers ] [, $cb->( $receipt, $err ) ] )
+=head2 abort([ %params ] [, $cb->( $receipt, $err ) ] )
 
 The method C<abort> is used to roll back a transaction.
 
-=head2 disconnect( [ %headers ] [, $cb->( $receipt, $err ) ] )
+=head2 disconnect( [ %params ] [, $cb->( $receipt, $err ) ] )
 
 A client can disconnect from the server at anytime by closing the socket but
 there is no guarantee that the previously sent frames have been received by
@@ -1280,7 +1283,7 @@ the server. To do a graceful shutdown, where the client is assured that all
 previous frames have been received by the server, you must call C<disconnect>
 method and wait for the C<RECEIPT> frame.
 
-=head2 execute( $command, [ %headers ] [, $cb->( $receipt, $err ) ] )
+=head2 execute( $command, [ %params ] [, $cb->( $receipt, $err ) ] )
 
 An alternative method to execute commands. In some cases it can be more
 convenient.
