@@ -4,7 +4,7 @@ use 5.008000;
 use strict;
 use warnings;
 
-our $VERSION = '0.08';
+our $VERSION = '0.10';
 
 use Encode qw( decode );
 
@@ -85,7 +85,7 @@ Gets frame body
 
 =head2 decoded_body()
 
-Gest decoded frame body
+Gets decoded frame body.
 
 =head1 SEE ALSO
 
